<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sw">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Chukie kichoko cha kipengele au kichukie kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Hakuchukie kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Matokeo ya kipengele</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Matokeo ya kipengele</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>Kichukie kipengele</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Matokeo ya kipengele</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Matokeo ya kipengele</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Ukambo wa kipengele uliokamwa. Tafakari kichukie kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Tafuta</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Matokeo ya kipengele imeshukieleka</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Chagua kipengele</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kichukie kipengele</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Kichukie kipengele kwa %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Kichukie kipengele</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Kichukie kipengele</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Kichukie kipengele kwa kipengele kwa kipengele, tafakari kichukie kipengele</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele kwa kipengele</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Matokeo ya kipengele</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>Matokeo ya kipengele uliokamwa.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Matokeo ya kipengele</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Kichukie kipengele kwa kipengele</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Kichukie kipengele</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Matokeo ya kipengele imeshukieleka na kichukie kipengele</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Kichukie kipengele</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Kichukie kipengele</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Kichukie kipengele</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Pinge Screenshot</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Record</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Kupatia</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Tazama</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Kupatia imepata</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Imesajiliwa %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Record</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Openda Magazeti</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Kupatia Screenshot itafanikiwa %1 sekondi</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Pata kazi ya kufanya.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Hakikia kupatia screenshot ya kuzalishia.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Ukumbuzi wa kwenye kati ya kuzalishia</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Ukumbuzi wa kwenye kati ya kuzalishia</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>Tafuta kuzalishia</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Kuzalishia kwenye kati ya kuzalishia kwa kuzingia kwenye kati ya kuzalishia</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Kuzalishia kwenye kati ya kuzalishia kwa kuzingia kwenye kati ya kuzalishia</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Area ya kwenye kati ya kuzalishia, klicka </translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Input text here</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/Screenshot</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Exit/Save</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Size Adjustment</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Settings</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Quick start</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Window screenshot</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Delay screenshot</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Full screenshot</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Exit</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Save</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Makuti</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Makuti mmoja</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Lipili</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Kipasi</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Moto</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Ondoa</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Kuondoa</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Tumia kipili kwa kwenye</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Tumia kipili kwa kwenye</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Tumia kipili kwa kwenye</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Tumia kipili kwa kwenye</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Tumia kipili kwa kwenye</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Tumia kipili kwa kwenye</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Tumia kipili kwa kwenye</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Tumia kipili kwa kwenye</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Msaada</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Ona kipasi</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sauti</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Kipasi</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Kamera</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Husishe kujisikiliza</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Matokeo</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Husishe kujisikiliza</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Mshangano</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Vifaa</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Ondoa moto</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Scrollshot</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Fungua screenshot</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>Husishe OCR</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Husishe scrollshot</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Kichaka</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Matokeo ya kamera</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Kurahisisha</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Kichaka
Pakua na hukua Shift ili kuzingia kichaka kikuu</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Mvuto
Pakua na hukua Shift ili kuzingia mvuto kikuu</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Machache
Pakua na hukua Shift ili kuzingia machache kikuu</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Pakua kuzingia kifua (Pakua na hukua ili kuzingia)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Pakua kuzingia kifua (Pakua na hukua ili kuzingia)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Pakua kuzingia kifua (Pakua na hukua ili kuzingia)</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>Pakua au hukua ili
chagua matokeo ya kamera</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Tazama kichwa (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Kufuta kichwa (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Tazama kichwa (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Pakua kamera (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Kufuta kamera (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Matokeo ya kamera</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Mipangilio</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Mipangilio (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Mipangilio:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Sauti</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofoni</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>Audio ya system</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Mipaka</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Tazama kifua</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Tazama kifua ya click</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Tafsiri kwenye</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Desktop</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videot</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>Kifua (R)
Kuchapisha na kuchangisha Shift kuchapisha kifua ya square</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>Kifua ya ellipse (O)
Kuchapisha na kuchangisha Shift kuchapisha kifua ya circle</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Kifua ya line (L)
Kuchapisha na kuchangisha Shift kuchapisha kifua ya vertical au horizontal line</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Kifua ya arrow (X)
Kuchapisha na kuchangisha Shift kuchapisha kifua ya vertical au horizontal arrow</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Pencil (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Blur (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Text (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Scrollshot (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Extract text (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Pin screenshots (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Undo (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Record</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Clipboard</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Pictures</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>Folder</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Tafsiri kifua ya path kwenye save</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Badilisha kifua ya path kwenye save</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Effekti ya Border</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Hakuna</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Shado</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Kamba</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Makini</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Ebakisha Mwongo</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Fungua (Esc)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>Sijambo (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Pakua mifano ya kusimamisha kwenye %1*%2 ili kupata matokeo ya video ya kutosha</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Kusimamisha screen ya kutosha haifikani</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Fungua</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>Kusimamisha mpya</translation>
    </message>
</context>
</TS>
